<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml" xmlns:o="urn:schemas-microsoft-com:office:office">
<head>
  <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
  <meta name="viewport" content="initial-scale=1.0">
  <meta name="format-detection" content="telephone=no">
  <title style="-ko-bind-text: @titleText">TITLE</title>
  <style type="text/css">
    @supports -ko-blockdefs {
      id { widget: id }
      size { label: Size; widget: select; options: 8|9|10|11|12|13|14|15|16|18|20|22|25|28|31; }
      visible { label: Visible?; widget: boolean }
      color { label: Color; widget: color }
      radius {
        label: Corner Radius;
        widget: integer;
        max: 20;
        help: Attention - this property is not supported on all email clients (i.e. Outlook)
      }
      face { label: Font; widget: select; options: Arial, Helvetica, sans-serif=Arial|Arial Black, Arial Black, Gadget, sans-serif=Arial Black|Comic Sans MS, Comic Sans MS5, cursive=Comic Sans|Courier New, Courier New, monospace=Courier|Georgia, serif=Georgia|Impact, sans-serif=Impact|Lucida Console, Monaco, monospace=Lucida Console|Lucida Sans Unicode, Lucida Grande, sans-serif=Lucida Sans Unicode|Times New Roman, Times, serif=Times New Roman|Verdana, Geneva, sans-serif=Verdana}
      decoration { label: Decoration; widget: select; options: none=None|underline=Underline }
      linksColor { label: Link Color; extend: color }
      linksDecoration { label: Underlined Links?; extend: decoration }
      buttonColor { label: Button Color; extend: color }
      text { label: Paragraph; widget: text }
      url { label: Link; widget: url }
      src { label: Image; widget: src }
      hrWidth { label: Width; widget: select; options:10|20|30|40|50|60|70|80|90|100; }
      hrHeight { label: Line height; widget: integer; max: 80; }

      height { label: Height; widget: integer }
      imageHeight { label: Image Height; extend: height; }
      lineHeight { label: Line Height; widget: select; options: normal=Normal|150%=1.5 Lines|200%=Double; }

      spacerSize { label: Height; widget: integer; max: 90; min: 4; }
      align { label: Alignment; widget: select; options:left=Left|right=Right|center=Center}
      alt {
        label: Alternative Text;
        widget: text;
        help: Alternative text will be shown on email clients that does not download image automatically;
      }
      sponsor { label: Sponsor; properties: visible=true src url alt; category: hidden }
      titleText {label:Title Text;category: hidden;}
      gutterVisible { label: Show Gutter; extend: visible }
      socialIconType { label: Icon Version; widget: select; options: bw=Black and White|colors=Colors; }
      bigSocialIconType { label: Icon Version; widget: select; options:bw=Black and White|colors=Colors|rdcol=Rounded Colors|rdbl=Rounded Black; }
      bigSocialIconSize { label: Icon Size; widget: select; options: 32=Small|48=Big; }

      preheaderLinkOption {
        label: Unsubscribe Link;
        widget: select;
        options: [profile_link]=Profile|[unsubscribe_link]=Unsubscribe|none=None;
        help: If -None- is selected, preHeader text will be shown;
      }
     
      hrStyle { label: Separator Style;properties:color hrWidth hrHeight; }
      hrStyle:preview { height: 200%; width: 200%; bottom: 20px; -ko-border-bottom: @[hrHeight]px solid @color; }
      preheaderVisible { label: Show Preheader; extend: visible; help: Preheader block is the first one on the top of the page. It contains web version link and optionally unsubscribe link or a preheader text that will be shown as a preview on some email clients; }

      /* content types */
      blocks { label: Blocks; properties: blocks[]; }
      link { label: Link; properties: text url }
      image { label: Image; properties: src url alt }
      backgroundColor { label: Background Color; extend: color }
      buttonLink { label: Button; extend: link }
      
      /* texts and links */
      textStyle { label: Text; properties: face color size align }
      textStyle:preview { -ko-bind-text: @['AaZz']; -ko-font-family: @face; -ko-color: @color; -ko-font-size: @[size]px; }
      linkStyle { label: Link; properties: face color size decoration=none }
      linkStyle:preview { -ko-bind-text: @['Link']; -ko-font-size: @[size]px; -ko-font-family: @face; -ko-color: @color; -ko-text-decoration: @[decoration] }
      longTextStyle { label: Paragraph; properties: face color size lineHeight align linksColor   }
      longTextStyle:preview { -ko-bind-text: @['AaZz']; -ko-font-family: @face; -ko-color: @color; -ko-font-size: @[size]px; }
      bigButtonStyle { label: Big Button; extend: buttonStyle }
      titleTextStyle { label: Title; extend: textStyle }
      /* background */
      externalBackgroundColor { label: External Background; extend: color }

      externalTextStyle { label: Alternative Text; extend: textStyle }
      externalTextStyle:preview { -ko-bind-text: @['AaZz']; -ko-font-family: @face; -ko-color: @color; -ko-font-size: @[size]px; }
     
      bigTitleStyle { label: Title; properties: face color size align}
      bigTitleStyle:preview { -ko-bind-text: @['AaZz']; -ko-font-family: @face; -ko-color: @color; -ko-font-size: @[size]px; }
      /* buttons */
      buttonStyle color { label: Text Color; extend: color }
      buttonStyle size { label: Text Size; extend: size }
      buttonStyle { label: Button; properties: face color size align buttonColor radius }
      buttonStyle:preview { -ko-bind-text: @['Button']; -ko-font-family: @face; -ko-color: @color; -ko-font-size: @[size]px; -ko-background-color: @buttonColor; padding-left: 5px; -ko-border-radius: @[radius]px; }
      
      /* contents */
      preheaderText {label: PreHeader Text; extend:text; help: This text will be shown on some email clients as a preview of the email contents;}
      leftImage { label: Left Image; extend: image }
      leftLongText { label: Left Text; extend: text }
      leftButtonLink { label: Left Button; extend: buttonLink }
      middleImage { label: Central Image; extend: image }
      middleLongText { label: Central Text; extend: text }
      middleButtonLink { label: Central Button; extend: buttonLink }
      rightImage { label: Right Image; extend: image }
      rightLongText { label: Right Text; extend: text }
      rightButtonLink { label: Right Button; extend: buttonLink }
      webversionText{ label: Web Link Text; extend: text;}
      unsubscribeText{ label: Unsubscribe Link; extend: text;}

      titleVisible { label: Show Title; extend: visible; }
      buttonVisible { label: Show Button; extend: visible; }
      imageVisible { label: Show Image; extend: visible; }

      contentTheme { label: Main Style; }
      contentTheme:preview { -ko-background-color: @[backgroundColor] }
      frameTheme { label: Frame Style; }
      frameTheme:preview { -ko-background-color: @[backgroundColor] }
      template preheaderText { label: Preheader; }

      template { label: Page; theme: frameTheme; properties: preheaderVisible=true; version: 1.1.16; }

      footerBlock { label: Unsubscribe Block; theme: frameTheme }
      
      fbVisible { label: Facebook; extend: visible }
      twVisible { label: Twitter; extend: visible }
      ggVisible { label: Google+; extend: visible }
      inVisible { label: LinkedIn; extend: visible }
      piVisible { label: Pinterest; extend: visible }
      flVisible { label: Flickr; extend: visible }
      viVisible { label: Vimeo; extend: visible }
      webVisible { label: Website; extend: visible }
      instVisible { label: Instagram; extend: visible }
      youVisible { label: YouTube; extend: visible }
      fbUrl { label: Facebook Link; extend: url }
      twUrl { label: Twitter Link; extend: url}
      ggUrl { label: Google+ Link; extend: url}
      inUrl { label: LinkedIn Link; extend: url}
      piUrl { label: Pinterest Link; extend: url}
      flUrl { label: Flickr Link; extend: url}
      viUrl { label: Vimeo Link; extend: url}
      webUrl { label: Website Link; extend: url}
      instUrl { label: Instagram Link; extend: url}
      youUrl { label: YouTube Link; extend: url}

      socialBlock {
        label: Social Block;
        properties: socialIconType=colors fbVisible=true fbUrl twVisible=true twUrl ggVisible=true ggUrl webVisible=false webUrl inVisible=false inUrl piVisible=false piUrl flVisible=false flUrl viVisible=false viUrl instVisible=false instUrl youVisible=false youUrl longTextStyle longText backgroundColor;
        variant:socialIconType;
        theme: frameTheme
      }

      bigSocialBlock {
        label: Big Social Block;
        properties: bigSocialIconType=rdcol bigSocialIconSize=48 fbVisible=true fbUrl twVisible=true twUrl ggVisible=true ggUrl webVisible=false webUrl inVisible=true inUrl piVisible=false piUrl flVisible=false flUrl viVisible=false viUrl instVisible=true instUrl youVisible=true youUrl longTextStyle longText;
        variant: bigSocialIconType;
        theme: contentTheme
      }


      shareButtonStyle iconColorType { label: Icon Color; widget: select; options: brand=Brand|white=White|black=Black; }
      shareButtonStyle color { label: Text Color; extend: color }
      shareButtonStyle size { label: Text Size; widget: select; options: 10|11|12|13|14|15|16|18|20|22|25; }
      shareButtonStyle { label: Share Button; properties: face iconColorType=black color size align buttonColor radius }
      shareButtonStyle:preview { -ko-bind-text: @['Button']; -ko-font-family: @face; -ko-color: @['black']; -ko-font-size: @[size]px; -ko-background-color: @['#CCCCCC']; padding-left: 5px; -ko-border-radius: @[radius]px; }

      shareButtonType { label: Button Version;widget: select; options:reverse=Brand buttons|simple=Brand icons|custom=Custom buttons; }
      shareBlock fbVisible { label: Facebook; }
      shareBlock twVisible { label: Twitter }
      shareBlock inVisible { label: LinkedIn }
      shareBlock ggVisible { label: Google+ }
      shareBlock piVisible { label: Pinterest }
      /* shareBlock shareUrlType { label: Share URL; widget: select; options:newsletter=Newsletter|custom=Custom;} */
      shareBlock customUrl { label: Share Link; }
      shareBlock {
        label: Share Block;
        /* shareUrlType=newsletter */
        properties: shareButtonType=reverse fbVisible=true twVisible=true inVisible=false ggVisible=true piVisible=false customUrl;
        variant: shareButtonType;
        theme: contentTheme;
      }
      
      preheaderBlock { label:Preheader Block;  theme: frameTheme}

      sideArticleBlock imagePos {label:Image position;widget:select; options: left=Left|right=Right; }
      sideArticleBlock imageWidth { label: Image Size; widget: select; options: 120=Small|166=Medium|258=Big; }
      sideArticleBlock { label: Image+Text Block; properties: backgroundColor titleVisible=true buttonVisible=true imageWidth=166 imagePos=left titleTextStyle longTextStyle buttonStyle  image  longText buttonLink; variant:imagePos; theme: contentTheme }

      textBlock { label: Text Block; properties: backgroundColor longTextStyle longText; theme: contentTheme}

      singleArticleBlock imageWidth { label: Image Size; widget: select; options: 166=Small|258=Medium|350=Big|534=Full }
      singleArticleBlock { label: Image/Text Block; properties: titleVisible=true buttonVisible=true imageVisible=true imageWidth=534 titleTextStyle longTextStyle buttonStyle  image  longText buttonLink; theme: contentTheme}

      fixedImageHeightVisible { label: Fix image height; extend: visible; }
      externalBackgroundVisible { label: Transparent background; extend: visible; }

      doubleArticleBlock { label: 2 Columns Block; properties: backgroundColor titleVisible=true buttonVisible=true imageVisible=true fixedImageHeightVisible=true titleTextStyle longTextStyle buttonStyle  leftImage  leftLongText leftButtonLink rightImage  rightLongText rightButtonLink; theme: contentTheme}

      tripleArticleBlock { label: 3 Columns Block; properties: backgroundColor titleVisible=true buttonVisible=true imageVisible=true fixedImageHeightVisible=true titleTextStyle longTextStyle buttonStyle  leftImage  leftLongText leftButtonLink middleImage  middleLongText middleButtonLink rightImage  rightLongText rightButtonLink; theme: contentTheme}
      
      logoBlock longTextStyle { label: Alternative Text; }
      logoBlock imageWidth { label: Image Size; widget: select; options: 166=Small|258=Medium|350=Big }
      logoBlock { label: Logo Block; properties: externalBackgroundVisible=true image imageWidth=258; variant: externalBackgroundVisible; theme: contentTheme}
      
      titleBlock { label: Title; theme: contentTheme}

      imageBlock longTextStyle { label: Alternative Text; }
      imageBlock { label: Image; properties: gutterVisible=false; variant: gutterVisible; theme: contentTheme }

      doubleImageBlock longTextStyle { label: Alternative Text; }
      doubleImageBlock { label: Two Image Gallery; properties: gutterVisible=false fixedImageHeightVisible=true; variant: gutterVisible; theme: contentTheme }

      tripleImageBlock longTextStyle { label: Alternative Text; }
      tripleImageBlock { label: Three Image Gallery;properties:gutterVisible=false fixedImageHeightVisible=true; variant: gutterVisible; theme: contentTheme}

      buttonBlock { label: Button Block; theme: contentTheme}
      hrBlock { label: Separator Block;  theme: contentTheme}
      /* imageSeparatorBlock { label: Image Separator Block;  theme: contentTheme} */
      spacerBlock { label: Spacer Block; properties: externalBackgroundVisible=true; theme: contentTheme}

      spacerBlock:preview,
      logoBlock:preview { -ko-background-color: @[externalBackgroundColor] }

      preheaderBlock:preview,
      hrBlock:preview,
      sideArticleBlock:preview,
      textBlock:preview,
      singleArticleBlock:preview,
      doubleArticleBlock:preview,
      tripleArticleBlock:preview,
      titleBlock:preview,
      footerBlock:preview,
      socialBlock:preview,
      buttonBlock:preview,
      titleBlock:preview { -ko-background-color: @[backgroundColor] }
    }
  </style>
  <style type="text/css" data-inline="true">
    body { margin: 0; padding: 0; }
    img { border: 0px; display: block; }

    .socialLinks { font-size: 6px; }
    .socialLinks a {
      display: inline-block;
    }

    .long-text p { margin: 1em 0px; }
    .long-text p:last-child { margin-bottom: 0px; }
    .long-text p:first-child { margin-top: 0px; }
  </style>
  <style type="text/css">
    /* yahoo, hotmail */
    .ExternalClass, .ExternalClass p, .ExternalClass span, .ExternalClass font, .ExternalClass td, .ExternalClass div { line-height: 100%; }
    .yshortcuts a { border-bottom: none !important; }
    .vb-outer { min-width: 0 !important; }
    .RMsgBdy, .ExternalClass {
      width: 100%;
      background-color: #3f3f3f;
      -ko-background-color: @[_theme_.frameTheme.backgroundColor]
    }

    /* outlook/office365 add buttons outside not-linked images and safari have 2px margin */
    [o365] button { margin: 0 !important; }

    /* outlook */
    table { mso-table-rspace: 0pt; mso-table-lspace: 0pt; }
    #outlook a { padding: 0; }
    img { outline: none; text-decoration: none; border: none; -ms-interpolation-mode: bicubic; }
    a img { border: none; }

    @media screen and (max-width: 600px) {
      table.vb-container, table.vb-row {
        width: 95% !important;
      }

      .mobile-hide { display: none !important; }
      .mobile-textcenter { text-align: center !important; }

      .mobile-full { 
        width: 100% !important;
        max-width: none !important;
      }
    }
    /* previously used also screen and (max-device-width: 600px) but Yahoo Mail doesn't support multiple queries */
  </style>
  <style type="text/css" data-inline="true">
    [data-ko-block=tripleArticleBlock] .links-color a, 
    [data-ko-block=tripleArticleBlock] .links-color a:link, 
    [data-ko-block=tripleArticleBlock] .links-color a:visited,
    [data-ko-block=tripleArticleBlock] .links-color a:hover {
      color: #3f3f3f;
      -ko-color: @longTextStyle.linksColor;
      text-decoration: underline;
    }

    [data-ko-block=doubleArticleBlock] .links-color a, 
    [data-ko-block=doubleArticleBlock] .links-color a:link, 
    [data-ko-block=doubleArticleBlock] .links-color a:visited,
    [data-ko-block=doubleArticleBlock] .links-color a:hover {
      color: #3f3f3f;
      -ko-color: @longTextStyle.linksColor;
      text-decoration: underline;
    }

    [data-ko-block=singleArticleBlock] .links-color a, 
    [data-ko-block=singleArticleBlock] .links-color a:link, 
    [data-ko-block=singleArticleBlock] .links-color a:visited,
    [data-ko-block=singleArticleBlock] .links-color a:hover {
      color: #3f3f3f;
      -ko-color: @longTextStyle.linksColor;
      text-decoration: underline;
    }

    [data-ko-block=textBlock] .links-color a, 
    [data-ko-block=textBlock] .links-color a:link, 
    [data-ko-block=textBlock] .links-color a:visited,
    [data-ko-block=textBlock] .links-color a:hover {
      color: #3f3f3f;
      -ko-color: @longTextStyle.linksColor;
      text-decoration: underline;
    }

    [data-ko-block=sideArticleBlock] .links-color a, 
    [data-ko-block=sideArticleBlock] .links-color a:link, 
    [data-ko-block=sideArticleBlock] .links-color a:visited,
    [data-ko-block=sideArticleBlock] .links-color a:hover {
      color: #3f3f3f;
      -ko-color: @longTextStyle.linksColor;
      text-decoration: underline;
    }

    [data-ko-block=socialBlock] .links-color a, 
    [data-ko-block=socialBlock] .links-color a:link, 
    [data-ko-block=socialBlock] .links-color a:visited,
    [data-ko-block=socialBlock] .links-color a:hover {
      color: #cccccc;
      -ko-color: @longTextStyle.linksColor;
      text-decoration: underline;
    }

    [data-ko-block=footerBlock] .links-color a, 
    [data-ko-block=footerBlock] .links-color a:link, 
    [data-ko-block=footerBlock] .links-color a:visited,
    [data-ko-block=footerBlock] .links-color a:hover {
      color: #cccccc;
      -ko-color: @longTextStyle.linksColor;
      text-decoration: underline;
    }

    [data-ko-block=doubleImageBlock] a,
    [data-ko-block=doubleImageBlock] a:link,
    [data-ko-block=doubleImageBlock] a:visited,
    [data-ko-block=doubleImageBlock] a:hover {
      color: #3f3f3f;
      -ko-color: @longTextStyle.linksColor;
      text-decoration: underline;
    }
    [data-ko-block=tripleImageBlock] a,
    [data-ko-block=tripleImageBlock] a:link,
    [data-ko-block=tripleImageBlock] a:visited,
    [data-ko-block=tripleImageBlock] a:hover {
      color: #3f3f3f;
      -ko-color: @longTextStyle.linksColor;
      text-decoration: underline;
    }
    [data-ko-block=imageBlock] a,
    [data-ko-block=imageBlock] a:link,
    [data-ko-block=imageBlock] a:visited,
    [data-ko-block=imageBlock] a:hover {
      color: #3f3f3f;
      -ko-color: @longTextStyle.linksColor;
      text-decoration: underline;
    }
  </style>
  
</head>
<body bgcolor="#3f3f3f" text="#919191" alink="#cccccc" vlink="#cccccc" style="background-color: #3f3f3f; color: #919191;
  -ko-background-color: @_theme_.frameTheme.backgroundColor; -ko-attr-bgcolor: @_theme_.frameTheme.backgroundColor; -ko-color: @_theme_.frameTheme.longTextStyle.color;
  -ko-attr-text: @_theme_.frameTheme.longTextStyle.color; -ko-attr-alink: @_theme_.frameTheme.longTextStyle.linksColor;
  -ko-attr-vlink: @_theme_.frameTheme.longTextStyle.linksColor"><center>

  <div data-ko-display="preheaderVisible" data-ko-wrap="false">

    
    <!-- preheaderBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#3f3f3f" style="background-color: #3f3f3f; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]" data-ko-block="preheaderBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <div data-ko-display="preheaderLinkOption neq 'none'" style="display: none; font-size:1px; line-height: 1px; max-height:0px; max-width: 0px; opacity: 0; overflow: hidden; 
          -ko-bind-text: @preheaderText"></div>
      <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 0px; border-spacing: 0px; max-width: 570px; -mru-width: 0px" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0; padding: 0 9px"><div style="width:100%; max-width: 552px; -mru-width: 0px"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="552"><tr><![endif]--><!--
        --><!--
          --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="276"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 276px; -mru-width: 0px; min-width: calc(276 * 100% / 552); -ko-min-width: @['calc(' + (276) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="276">
          
            <tr data-ko-display="preheaderLinkOption neq 'none'"><td width="100%" valign="top" style="font-weight: normal; color: #ffffff; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: left; -ko-font-size: @[linkStyle.size]px; -ko-color: @linkStyle.color; -ko-font-family: @linkStyle.face" align="left"><a style="color: #ffffff; text-decoration: underline; -ko-attr-href: @[preheaderLinkOption]; -ko-color: @linkStyle.color; -ko-text-decoration: @linkStyle.decoration" href="[unsubscribe_link]" data-ko-editable="unsubscribeText">Unsubscribe</a></td></tr>
            <tr data-ko-display="preheaderLinkOption eq 'none'" style="display: none">
      <td width="100%" valign="top" style="font-weight: normal; color: #919191; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: left; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-text-align: @longTextStyle.align; -ko-attr-align: @longTextStyle.align" align="left"><span style="font-weight: normal; -ko-bind-text: @preheaderText"></span></td>
    </tr>
          
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
          --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="276" class="mobile-hide"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 276px; -mru-width: 0px; min-width: calc(276 * 100% / 552); -ko-min-width: @['calc(' + (276) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full mobile-hide"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="276">
          
            <tr><td width="100%" valign="top" style="font-weight: normal; color: #ffffff; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: right; -ko-font-size: @[linkStyle.size]px; -ko-color: @linkStyle.color; -ko-font-family: @linkStyle.face" align="right"><a style="color: #ffffff; text-decoration: underline; -ko-color: @linkStyle.color; -ko-text-decoration: @linkStyle.decoration" href="[show_link]" data-ko-editable="webversionText">View in your browser</a></td></tr>
          
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
        --><!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
    </td></tr>
    </table>
    <!-- /preheaderBlock -->
    

  </div>

  <div data-ko-container="main" data-ko-wrap="false">

    
    <!-- logoBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="logoBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <div data-ko-wrap="false" style="width: 100%; display:inline-block" data-ko-display="externalBackgroundVisible"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="display:inline-block; vertical-align:top; width:100%; max-width: 276px; -mru-width: 0px; -ko-max-width: @[18 + Math.round(imageWidth) + 'px']"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; -ko-attr-width: @[18 + Math.round(imageWidth)]; mso-cellspacing: 9px; border-spacing: 9px" width="276">
          
          <!-- TODO nel template originale abbiamo anche un font-size: 18px, externalTextStyle.size ... -->
          <tr><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 258px; -mru-width: 0px; -ko-width: @[imageWidth]px"><![endif]--><a href="" data-ko-link="image.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #f3f3f3; font-size: 18px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[externalTextStyle.size]px; -ko-color: @externalTextStyle.color; -ko-font-family: @externalTextStyle.face; -ko-attr-alt: @image.alt; width: 100%; max-width: 258px; -ko-attr-width: @[imageWidth]; -ko-max-width: @[imageWidth]px; height: auto" data-ko-editable="image.src" width="258" data-ko-placeholder-height="150" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=258%2C150"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
        
        </table></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
      <div data-ko-wrap="false" style="width: 100%; display:inline-block; display: none" data-ko-display="externalBackgroundVisible eq false"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="display:inline-block; vertical-align:top; width:100%; max-width: 276px; -mru-width: 0px; -ko-max-width: @[18 + Math.round(imageWidth) + 'px']"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; -ko-attr-width: @[18 + Math.round(imageWidth)]; mso-cellspacing: 9px; border-spacing: 9px" width="276">
          
          <!-- TODO nel template originale abbiamo anche un font-size: 18px, externalTextStyle.size ... -->
          <tr><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 258px; -mru-width: 0px; -ko-width: @[imageWidth]px"><![endif]--><a href="" data-ko-link="image.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @image.alt; width: 100%; max-width: 258px; -ko-attr-width: @[imageWidth]; -ko-max-width: @[imageWidth]px; height: auto" data-ko-editable="image.src" width="258" data-ko-placeholder-height="150" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=258%2C150"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
        
        </table></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
    </td></tr>
    </table>
    <!-- /logoBlock -->
    

    
    <!-- sideArticleBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="sideArticleBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="width:100%; max-width: 552px; -mru-width: 0px"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="552"><tr><![endif]--><!--
        --><!--
          --><div data-ko-wrap="false" style="display:inline-block; width: 100%; max-width: 184px; -mru-width: 0px; -ko-max-width: @[18 + Math.round(imageWidth) + 'px']; min-width: calc(184 * 100% / 552); -ko-min-width: @['calc(' + (true ? 18 + Math.round(imageWidth) : 184) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full" data-ko-display="imagePos eq 'left'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="imagePos eq 'left'" width="184" style="-ko-attr-width: @[18 + Math.round(imageWidth)]"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 184px; -mru-width: 0px; -ko-max-width: @[18 + Math.round(imageWidth) + 'px']; min-width: calc(184 * 100% / 552); -ko-min-width: @['calc(' + (true ? 18 + Math.round(imageWidth) : 184) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; -ko-attr-width: @[18 + Math.round(imageWidth)]; mso-cellspacing: 9px; border-spacing: 9px" width="184">
          
            <tr><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px; -ko-width: @[imageWidth]px"><![endif]--><a href="" data-ko-link="image.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @image.alt; width: 100%; max-width: 166px; -ko-attr-width: @[imageWidth]; -ko-max-width: @[imageWidth]px; height: auto" data-ko-editable="image.src" width="166" data-ko-placeholder-height="130" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C130"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
          
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div><!--
          --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="368" style="-ko-attr-width: @[570 - 2 * 18 - Math.round(imageWidth)]"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 368px; -mru-width: 0px; -ko-max-width: @[570 - 2 * 18 - Math.round(imageWidth) + 'px']; min-width: calc(368 * 100% / 552); -ko-min-width: @['calc(' + (true ? 570 - 2 * 18 - Math.round(imageWidth) : 368) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; -ko-attr-width: @[570 - 2 * 18 - Math.round(imageWidth)]; mso-cellspacing: 9px; border-spacing: 9px" width="368">
          
            <!-- TODO class="title" -->
            <tr data-ko-display="titleVisible">
      <td width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 18px; font-family: Arial, Helvetica, sans-serif; text-align: left; -ko-font-size: @[titleTextStyle.size]px; -ko-color: @titleTextStyle.color; -ko-font-family: @titleTextStyle.face; -ko-text-align: @titleTextStyle.align; -ko-attr-align: @titleTextStyle.align" align="left"><span style="font-weight: normal" data-ko-editable="titleText">Title</span></td>
    </tr>
            <tr><td class="long-text links-color" width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: left; line-height: normal; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-text-align: @longTextStyle.align; -ko-attr-align: @longTextStyle.align; -ko-line-height: @[longTextStyle.lineHeight]" align="left" data-ko-editable="longText"><p>Far far away, behind the word mountains, far from the countries <a href="">Vokalia and Consonantia</a>, there live the blind texts. Separated they live in Bookmarksgrove right at the coast of the Semantics, a large language ocean. A small river named Duden flows by their place and supplies it with the necessary regelialia.</p></td></tr>
            <tr data-ko-display="buttonVisible">
      <td valign="top" align="left" style="-ko-attr-align: @buttonStyle.align"><table cellpadding="6" border="0" align="left" cellspacing="0" style="border-spacing: 0; mso-padding-alt: 6px 6px 6px 6px; padding-top: 4px; -ko-attr-align: @buttonStyle.align"><tr data-ko-display="buttonVisible">
        <td width="auto" valign="middle" align="left" style="text-align:center; font-weight: normal; padding: 6px; padding-left: 18px; padding-right: 18px; background-color: #bfbfbf; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; border-radius: 4px; -ko-border-radius: @[buttonStyle.radius]px; -ko-attr-bgcolor: @buttonStyle.buttonColor; -ko-background-color: @buttonStyle.buttonColor; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-align: @buttonStyle.align" bgcolor="#bfbfbf"><a href="" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-href: @buttonLink.url"><span data-ko-wrap="false" data-ko-editable="buttonLink.text">BUTTON</span></a></td>
      </tr></table></td>
    </tr>
          
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
          --><div data-ko-wrap="false" style="display:inline-block; display: none; width: 100%; max-width: 184px; -mru-width: 0px; -ko-max-width: @[18 + Math.round(imageWidth) + 'px']; min-width: calc(184 * 100% / 552); -ko-min-width: @['calc(' + (true ? 18 + Math.round(imageWidth) : 184) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full" data-ko-display="imagePos eq 'right'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="imagePos eq 'right'" style="display: none; -ko-attr-width: @[18 + Math.round(imageWidth)]" width="184"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 184px; -mru-width: 0px; -ko-max-width: @[18 + Math.round(imageWidth) + 'px']; min-width: calc(184 * 100% / 552); -ko-min-width: @['calc(' + (true ? 18 + Math.round(imageWidth) : 184) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; -ko-attr-width: @[18 + Math.round(imageWidth)]; mso-cellspacing: 9px; border-spacing: 9px" width="184">
          
            <tr><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px; -ko-width: @[imageWidth]px"><![endif]--><a href="" data-ko-link="image.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @image.alt; width: 100%; max-width: 166px; -ko-attr-width: @[imageWidth]; -ko-max-width: @[imageWidth]px; height: auto" data-ko-editable="image.src" width="166" data-ko-placeholder-height="130" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C130"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
          
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div><!--
        --><!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
    </td></tr>
    </table>
    <!-- /sideArticleBlock -->
    

    
    <!-- singleArticleBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="singleArticleBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="display:inline-block; vertical-align:top; width:100%; max-width: 552px; -mru-width: 0px"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="552">
          
          <tr data-ko-display="imageVisible"><td width="100%" valign="top" align="center" class="links-color" style="padding-bottom: 9px"><!--[if (lte ie 8)]><div style="display: inline-block; width: 534px; -mru-width: 0px; -ko-width: @[imageWidth]px"><![endif]--><a href="" data-ko-link="image.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @image.alt; width: 100%; max-width: 534px; -ko-attr-width: @[imageWidth]; -ko-max-width: @[imageWidth]px; height: auto" data-ko-editable="image.src" width="534" data-ko-placeholder-height="150" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=534%2C150"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
          <!-- TODO class="title" -->
          <tr data-ko-display="titleVisible">
      <td width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 18px; font-family: Arial, Helvetica, sans-serif; text-align: left; -ko-font-size: @[titleTextStyle.size]px; -ko-color: @titleTextStyle.color; -ko-font-family: @titleTextStyle.face; -ko-text-align: @titleTextStyle.align; -ko-attr-align: @titleTextStyle.align" align="left"><span style="font-weight: normal" data-ko-editable="text">Section Title</span></td>
    </tr>
          <tr><td class="long-text links-color" width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: left; line-height: normal; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-text-align: @longTextStyle.align; -ko-attr-align: @longTextStyle.align; -ko-line-height: @[longTextStyle.lineHeight]" align="left" data-ko-editable="longText"><p>Far far away, behind the word mountains, far from the countries <a href="">Vokalia and Consonantia</a>, there live the blind texts. Separated they live in Bookmarksgrove right at the coast of the Semantics, a large language ocean. A small river named Duden flows by their place and supplies it with the necessary regelialia.</p></td></tr>
          <tr data-ko-display="buttonVisible">
      <td valign="top" align="left" style="-ko-attr-align: @buttonStyle.align"><table cellpadding="6" border="0" align="left" cellspacing="0" style="border-spacing: 0; mso-padding-alt: 6px 6px 6px 6px; padding-top: 4px; -ko-attr-align: @buttonStyle.align"><tr data-ko-display="buttonVisible">
        <td width="auto" valign="middle" align="left" style="text-align:center; font-weight: normal; padding: 6px; padding-left: 18px; padding-right: 18px; background-color: #bfbfbf; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; border-radius: 4px; -ko-border-radius: @[buttonStyle.radius]px; -ko-attr-bgcolor: @buttonStyle.buttonColor; -ko-background-color: @buttonStyle.buttonColor; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-align: @buttonStyle.align" bgcolor="#bfbfbf"><a href="" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-href: @buttonLink.url"><span data-ko-wrap="false" data-ko-editable="buttonLink.text">BUTTON</span></a></td>
      </tr></table></td>
    </tr>
        
        </table></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
    </td></tr>
    </table>
    <!-- /singleArticleBlock -->
    

    
    <!-- titleBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="titleBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="0" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 0px; border-spacing: 0px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0; padding: 0 9px"><div style="display:inline-block; vertical-align:top; width:100%; max-width: 552px; -mru-width: 0px"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="552">
          
          <!-- TODO class="title" -->
          <tr>
      <td width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 22px; font-family: Arial, Helvetica, sans-serif; text-align: center; -ko-font-size: @[bigTitleStyle.size]px; -ko-color: @bigTitleStyle.color; -ko-font-family: @bigTitleStyle.face; -ko-text-align: @bigTitleStyle.align; -ko-attr-align: @bigTitleStyle.align" align="center"><span style="font-weight: normal" data-ko-editable="text">Section Title</span></td>
    </tr>
        
        </table></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
    </td></tr>
    </table>
    <!-- /titleBlock -->
    

    
    <!-- textBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="textBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="18" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 18px; border-spacing: 18px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-container">
        
        <tr><td class="long-text links-color" width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: left; line-height: normal; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-text-align: @longTextStyle.align; -ko-attr-align: @longTextStyle.align; -ko-line-height: @[longTextStyle.lineHeight]" align="left" data-ko-editable="longText"><p>Far far away, behind the word mountains, far from the countries <a href="">Vokalia and Consonantia</a>, there live the blind texts.</p>
          <p>Separated they live in Bookmarksgrove right at the coast of the Semantics, a large language ocean. A small river named Duden flows by their place and supplies it with the necessary regelialia.</p></td></tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
    </td></tr>
    </table>
    <!-- /textBlock -->
    

    
    <!-- tripleArticleBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="tripleArticleBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
      <!-- TODO implementare gestione attributi nel repeater -->
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="width:100%; max-width: 552px; -mru-width: 0px"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="552"><tr><![endif]--><!--
        --><!--
          --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="184"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 184px; -mru-width: 0px; min-width: calc(184 * 100% / 552); -ko-min-width: @['calc(' + (184) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="184">
          
            <tr data-ko-display="imageVisible and fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color" style="padding-bottom: 9px"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 166px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="leftImage.src" width="166" height="90" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C90"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            <tr data-ko-display="imageVisible and fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color" style="padding-bottom: 9px"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 166px; height: auto" data-ko-editable="leftImage.src" width="166" data-ko-placeholder-height="90" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C100"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            <tr data-ko-display="titleVisible">
      <td width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 18px; font-family: Arial, Helvetica, sans-serif; text-align: left; -ko-font-size: @[titleTextStyle.size]px; -ko-color: @titleTextStyle.color; -ko-font-family: @titleTextStyle.face; -ko-text-align: @titleTextStyle.align; -ko-attr-align: @titleTextStyle.align" align="left"><span style="font-weight: normal" data-ko-editable="leftTitleText">Title</span></td>
    </tr>
            <tr><td class="long-text links-color" width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: left; line-height: normal; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-text-align: @longTextStyle.align; -ko-attr-align: @longTextStyle.align; -ko-line-height: @[longTextStyle.lineHeight]" align="left" data-ko-editable="leftLongText"><p>Far far away, behind the word mountains, far from the countries <a href="">Vokalia and Consonantia</a>, there live the blind texts.</p></td></tr>
            <tr data-ko-display="buttonVisible">
      <td valign="top" align="left" style="-ko-attr-align: @buttonStyle.align"><table cellpadding="6" border="0" align="left" cellspacing="0" style="border-spacing: 0; mso-padding-alt: 6px 6px 6px 6px; padding-top: 4px; -ko-attr-align: @buttonStyle.align"><tr data-ko-display="buttonVisible">
        <td width="auto" valign="middle" align="left" style="text-align:center; font-weight: normal; padding: 6px; padding-left: 18px; padding-right: 18px; background-color: #bfbfbf; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; border-radius: 4px; -ko-border-radius: @[buttonStyle.radius]px; -ko-attr-bgcolor: @buttonStyle.buttonColor; -ko-background-color: @buttonStyle.buttonColor; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-align: @buttonStyle.align" bgcolor="#bfbfbf"><a href="" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-href: @leftButtonLink.url"><span data-ko-wrap="false" data-ko-editable="leftButtonLink.text">BUTTON</span></a></td>
      </tr></table></td>
    </tr>
          
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
        --><!--
          --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="184"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 184px; -mru-width: 0px; min-width: calc(184 * 100% / 552); -ko-min-width: @['calc(' + (184) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="184">
          
            <tr data-ko-display="imageVisible and fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color" style="padding-bottom: 9px"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="middleImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @middleImage.alt; width: 100%; max-width: 166px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="middleImage.src" width="166" height="90" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C90"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            <tr data-ko-display="imageVisible and fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color" style="padding-bottom: 9px"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="middleImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @middleImage.alt; width: 100%; max-width: 166px; height: auto" data-ko-editable="middleImage.src" width="166" data-ko-placeholder-height="70" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C100"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            <tr data-ko-display="titleVisible">
      <td width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 18px; font-family: Arial, Helvetica, sans-serif; text-align: left; -ko-font-size: @[titleTextStyle.size]px; -ko-color: @titleTextStyle.color; -ko-font-family: @titleTextStyle.face; -ko-text-align: @titleTextStyle.align; -ko-attr-align: @titleTextStyle.align" align="left"><span style="font-weight: normal" data-ko-editable="middleTitleText">Title</span></td>
    </tr>
            <tr><td class="long-text links-color" width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: left; line-height: normal; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-text-align: @longTextStyle.align; -ko-attr-align: @longTextStyle.align; -ko-line-height: @[longTextStyle.lineHeight]" align="left" data-ko-editable="middleLongText"><p>Far far away, behind the word mountains, far from the countries <a href="">Vokalia and Consonantia</a>, there live the blind texts.</p></td></tr>
            <tr data-ko-display="buttonVisible">
      <td valign="top" align="left" style="-ko-attr-align: @buttonStyle.align"><table cellpadding="6" border="0" align="left" cellspacing="0" style="border-spacing: 0; mso-padding-alt: 6px 6px 6px 6px; padding-top: 4px; -ko-attr-align: @buttonStyle.align"><tr data-ko-display="buttonVisible">
        <td width="auto" valign="middle" align="left" style="text-align:center; font-weight: normal; padding: 6px; padding-left: 18px; padding-right: 18px; background-color: #bfbfbf; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; border-radius: 4px; -ko-border-radius: @[buttonStyle.radius]px; -ko-attr-bgcolor: @buttonStyle.buttonColor; -ko-background-color: @buttonStyle.buttonColor; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-align: @buttonStyle.align" bgcolor="#bfbfbf"><a href="" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-href: @middleButtonLink.url"><span data-ko-wrap="false" data-ko-editable="middleButtonLink.text">BUTTON</span></a></td>
      </tr></table></td>
    </tr>
          
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
        --><!--
          --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="184"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 184px; -mru-width: 0px; min-width: calc(184 * 100% / 552); -ko-min-width: @['calc(' + (184) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="184">
          
            <tr data-ko-display="imageVisible and fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color" style="padding-bottom: 9px"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 166px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="rightImage.src" width="166" height="90" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C90"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            <tr data-ko-display="imageVisible and fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color" style="padding-bottom: 9px"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 166px; height: auto" data-ko-editable="rightImage.src" width="166" data-ko-placeholder-height="110" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C100"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            <tr data-ko-display="titleVisible">
      <td width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 18px; font-family: Arial, Helvetica, sans-serif; text-align: left; -ko-font-size: @[titleTextStyle.size]px; -ko-color: @titleTextStyle.color; -ko-font-family: @titleTextStyle.face; -ko-text-align: @titleTextStyle.align; -ko-attr-align: @titleTextStyle.align" align="left"><span style="font-weight: normal" data-ko-editable="rightTitleText">Title</span></td>
    </tr>
            <tr><td class="long-text links-color" width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: left; line-height: normal; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-text-align: @longTextStyle.align; -ko-attr-align: @longTextStyle.align; -ko-line-height: @[longTextStyle.lineHeight]" align="left" data-ko-editable="rightLongText"><p>Far far away, behind the word mountains, far from the countries <a href="">Vokalia and Consonantia</a>, there live the blind texts.</p></td></tr>
            <tr data-ko-display="buttonVisible">
      <td valign="top" align="left" style="-ko-attr-align: @buttonStyle.align"><table cellpadding="6" border="0" align="left" cellspacing="0" style="border-spacing: 0; mso-padding-alt: 6px 6px 6px 6px; padding-top: 4px; -ko-attr-align: @buttonStyle.align"><tr data-ko-display="buttonVisible">
        <td width="auto" valign="middle" align="left" style="text-align:center; font-weight: normal; padding: 6px; padding-left: 18px; padding-right: 18px; background-color: #bfbfbf; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; border-radius: 4px; -ko-border-radius: @[buttonStyle.radius]px; -ko-attr-bgcolor: @buttonStyle.buttonColor; -ko-background-color: @buttonStyle.buttonColor; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-align: @buttonStyle.align" bgcolor="#bfbfbf"><a href="" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-href: @rightButtonLink.url"><span data-ko-wrap="false" data-ko-editable="rightButtonLink.text">BUTTON</span></a></td>
      </tr></table></td>
    </tr>
          
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
        --><!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
    </td></tr>
    </table>
    <!-- /tripleArticleBlock -->
    

    
    <!-- doubleArticleBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="doubleArticleBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="width:100%; max-width: 552px; -mru-width: 0px"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="552"><tr><![endif]--><!--
        --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="276"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 276px; -mru-width: 0px; min-width: calc(276 * 100% / 552); -ko-min-width: @['calc(' + (276) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="276">
          
              <tr data-ko-display="imageVisible and fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color" style="padding-bottom: 9px"><!--[if (lte ie 8)]><div style="display: inline-block; width: 258px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 258px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="leftImage.src" width="258" height="100" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=258%2C100"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="imageVisible and fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color" style="padding-bottom: 9px"><!--[if (lte ie 8)]><div style="display: inline-block; width: 258px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 258px; height: auto" data-ko-editable="leftImage.src" width="258" data-ko-placeholder-height="120" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=258%2C120"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="titleVisible">
      <td width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 18px; font-family: Arial, Helvetica, sans-serif; text-align: left; -ko-font-size: @[titleTextStyle.size]px; -ko-color: @titleTextStyle.color; -ko-font-family: @titleTextStyle.face; -ko-text-align: @titleTextStyle.align; -ko-attr-align: @titleTextStyle.align" align="left"><span style="font-weight: normal" data-ko-editable="leftTitleText">Title</span></td>
    </tr>
              <tr><td class="long-text links-color" width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: left; line-height: normal; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-text-align: @longTextStyle.align; -ko-attr-align: @longTextStyle.align; -ko-line-height: @[longTextStyle.lineHeight]" align="left" data-ko-editable="leftLongText"><p>Far far away, behind the word mountains, far from the countries <a href="">Vokalia and Consonantia</a>, there live the blind texts.</p></td></tr>
              <tr data-ko-display="buttonVisible">
      <td valign="top" align="left" style="-ko-attr-align: @buttonStyle.align"><table cellpadding="6" border="0" align="left" cellspacing="0" style="border-spacing: 0; mso-padding-alt: 6px 6px 6px 6px; padding-top: 4px; -ko-attr-align: @buttonStyle.align"><tr data-ko-display="buttonVisible">
        <td width="auto" valign="middle" align="left" style="text-align:center; font-weight: normal; padding: 6px; padding-left: 18px; padding-right: 18px; background-color: #bfbfbf; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; border-radius: 4px; -ko-border-radius: @[buttonStyle.radius]px; -ko-attr-bgcolor: @buttonStyle.buttonColor; -ko-background-color: @buttonStyle.buttonColor; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-align: @buttonStyle.align" bgcolor="#bfbfbf"><a href="" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-href: @leftButtonLink.url"><span data-ko-wrap="false" data-ko-editable="leftButtonLink.text">BUTTON</span></a></td>
      </tr></table></td>
    </tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
          --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="276"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 276px; -mru-width: 0px; min-width: calc(276 * 100% / 552); -ko-min-width: @['calc(' + (276) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="276">
          
              <tr data-ko-display="imageVisible and fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color" style="padding-bottom: 9px"><!--[if (lte ie 8)]><div style="display: inline-block; width: 258px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 258px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="rightImage.src" width="258" height="100" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=258%2C100"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="imageVisible and fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color" style="padding-bottom: 9px"><!--[if (lte ie 8)]><div style="display: inline-block; width: 258px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 258px; height: auto" data-ko-editable="rightImage.src" width="258" data-ko-placeholder-height="120" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=258%2C120"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="titleVisible">
      <td width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 18px; font-family: Arial, Helvetica, sans-serif; text-align: left; -ko-font-size: @[titleTextStyle.size]px; -ko-color: @titleTextStyle.color; -ko-font-family: @titleTextStyle.face; -ko-text-align: @titleTextStyle.align; -ko-attr-align: @titleTextStyle.align" align="left"><span style="font-weight: normal" data-ko-editable="rightTitleText">Title</span></td>
    </tr>
              <tr><td class="long-text links-color" width="100%" valign="top" style="font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: left; line-height: normal; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-text-align: @longTextStyle.align; -ko-attr-align: @longTextStyle.align; -ko-line-height: @[longTextStyle.lineHeight]" align="left" data-ko-editable="rightLongText"><p>Far far away, behind the word mountains, far from the countries <a href="">Vokalia and Consonantia</a>, there live the blind texts.</p></td></tr>
              <tr data-ko-display="buttonVisible">
      <td valign="top" align="left" style="-ko-attr-align: @buttonStyle.align"><table cellpadding="6" border="0" align="left" cellspacing="0" style="border-spacing: 0; mso-padding-alt: 6px 6px 6px 6px; padding-top: 4px; -ko-attr-align: @buttonStyle.align"><tr data-ko-display="buttonVisible">
        <td width="auto" valign="middle" align="left" style="text-align:center; font-weight: normal; padding: 6px; padding-left: 18px; padding-right: 18px; background-color: #bfbfbf; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; border-radius: 4px; -ko-border-radius: @[buttonStyle.radius]px; -ko-attr-bgcolor: @buttonStyle.buttonColor; -ko-background-color: @buttonStyle.buttonColor; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-align: @buttonStyle.align" bgcolor="#bfbfbf"><a href="" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[buttonStyle.size]px; -ko-color: @buttonStyle.color; -ko-font-family: @buttonStyle.face; -ko-attr-href: @rightButtonLink.url"><span data-ko-wrap="false" data-ko-editable="rightButtonLink.text">BUTTON</span></a></td>
      </tr></table></td>
    </tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
          --><!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
    </td></tr>
    </table>
    <!-- /doubleArticleBlock -->
    

    
    <!-- hrBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="hrBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="0" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 0px; border-spacing: 0px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0; padding: 0 9px"><div style="display:inline-block; vertical-align:top; width:100%; max-width: 552px; -mru-width: 0px"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="552">
          
          <tr>
      <td valign="top" align="center"><table width="100%" cellspacing="0" cellpadding="0" border="0" style="border-spacing: 0; width: 100%; -ko-width: @[hrStyle.hrWidth]%; -ko-attr-width: @[hrStyle.hrWidth]%"><tr>
        <td width="100%" height="1" style="padding: 0; font-size:1px; line-height: 1px; width: 100%; background-color: #3f3f3f; line-height: 1px; -ko-background-color: @hrStyle.color; -ko-attr-height: @hrStyle.hrHeight; -ko-line-height: @[hrStyle.hrHeight]px">&nbsp;</td>
      </tr></table></td>
    </tr>
        
        </table></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
    </td></tr>
    </table>
    <!-- /hrBlock -->
    

    
    <!-- buttonBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="buttonBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="18" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 18px; border-spacing: 18px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-container">
        
        <tr>
      <td valign="top" align="center" style="-ko-attr-align: @bigButtonStyle.align"><table cellpadding="12" border="0" align="center" cellspacing="0" style="border-spacing: 0; mso-padding-alt: 12px 12px 12px 12px; -ko-attr-align: @bigButtonStyle.align"><tr>
        <td width="auto" valign="middle" align="center" style="text-align:center; font-weight: normal; padding: 12px; padding-left: 14px; padding-right: 14px; background-color: #bfbfbf; color: #3f3f3f; font-size: 22px; font-family: Arial, Helvetica, sans-serif; border-radius: 4px; -ko-border-radius: @[bigButtonStyle.radius]px; -ko-attr-bgcolor: @bigButtonStyle.buttonColor; -ko-background-color: @bigButtonStyle.buttonColor; -ko-font-size: @[bigButtonStyle.size]px; -ko-color: @bigButtonStyle.color; -ko-font-family: @bigButtonStyle.face; -ko-attr-align: @bigButtonStyle.align" bgcolor="#bfbfbf"><a href="" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 22px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[bigButtonStyle.size]px; -ko-color: @bigButtonStyle.color; -ko-font-family: @bigButtonStyle.face; -ko-attr-href: @link.url"><span data-ko-wrap="false" data-ko-editable="link.text">BUTTON</span></a></td>
      </tr></table></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
    </td></tr>
    </table>
    <!-- /buttonBlock -->
    

    
    <!-- imageBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="imageBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <div data-ko-wrap="false" style="width: 100%; display:inline-block" data-ko-display="gutterVisible eq false"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="0" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 0px; border-spacing: 0px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-container">
        
        <tr><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 570px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="image.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @image.alt; width: 100%; max-width: 570px; height: auto" data-ko-editable="image.src" width="570" data-ko-placeholder-height="200" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=570%2C200" class="mobile-full"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
      <div data-ko-wrap="false" style="width: 100%; display:inline-block; display: none" data-ko-display="gutterVisible"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="18" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 18px; border-spacing: 18px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-container">
        
        <tr><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 534px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="image.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @image.alt; width: 100%; max-width: 534px; height: auto" data-ko-editable="image.src" width="534" data-ko-placeholder-height="280" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=534%2C280"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
    </td></tr>
    </table>
    <!-- /imageBlock -->
    

    
    <!-- doubleImageBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="doubleImageBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <div data-ko-wrap="false" style="width: 100%; display:inline-block" data-ko-display="gutterVisible eq false"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="0" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 0px; border-spacing: 0px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="width:100%; max-width: 570px; -mru-width: 0px"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><![endif]--><!--
        --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="285"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 285px; -mru-width: 0px; min-width: calc(285 * 100% / 570); -ko-min-width: @['calc(' + (285) * 100 / 570 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(570 * 570px - 570 * 100%); -ko-width: @['calc('+ 570 * 570 + 'px - ' + 570 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="0" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 0px; border-spacing: 0px" width="285">
          
              <tr data-ko-display="fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 285px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 285px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="leftImage.src" width="285" height="180" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=285%2C180" class="mobile-full"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 285px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 285px; height: auto" data-ko-editable="leftImage.src" width="285" data-ko-placeholder-height="180" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=285%2C180" class="mobile-full"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
          --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="285"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 285px; -mru-width: 0px; min-width: calc(285 * 100% / 570); -ko-min-width: @['calc(' + (285) * 100 / 570 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(570 * 570px - 570 * 100%); -ko-width: @['calc('+ 570 * 570 + 'px - ' + 570 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="0" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 0px; border-spacing: 0px" width="285">
          
              <tr data-ko-display="fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 285px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 285px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="rightImage.src" width="285" height="180" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=285%2C180" class="mobile-full"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 285px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 285px; height: auto" data-ko-editable="rightImage.src" width="285" data-ko-placeholder-height="180" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=285%2C180" class="mobile-full"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
          --><!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
      <div data-ko-wrap="false" style="width: 100%; display:inline-block; display: none" data-ko-display="gutterVisible"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="width:100%; max-width: 552px; -mru-width: 0px"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="552"><tr><![endif]--><!--
        --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="276"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 276px; -mru-width: 0px; min-width: calc(276 * 100% / 552); -ko-min-width: @['calc(' + (276) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="276">
          
              <tr data-ko-display="fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 258px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 258px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="leftImage.src" width="258" height="180" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=258%2C180"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 258px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 258px; height: auto" data-ko-editable="leftImage.src" width="258" data-ko-placeholder-height="180" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=258%2C180"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
      --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="276"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 276px; -mru-width: 0px; min-width: calc(276 * 100% / 552); -ko-min-width: @['calc(' + (276) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="276">
          
              <tr data-ko-display="fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 258px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 258px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="rightImage.src" width="258" height="180" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=258%2C180"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 258px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 258px; height: auto" data-ko-editable="rightImage.src" width="258" data-ko-placeholder-height="180" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=258%2C180"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
      --><!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
    </td></tr>
    </table>
    <!-- /doubleImageBlock -->
    

    
    <!-- tripleImageBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="tripleImageBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <div data-ko-wrap="false" style="width: 100%; display:inline-block" data-ko-display="gutterVisible eq false"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="0" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 0px; border-spacing: 0px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="width:100%; max-width: 570px; -mru-width: 0px"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><![endif]--><!--
        --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="190"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 190px; -mru-width: 0px; min-width: calc(190 * 100% / 570); -ko-min-width: @['calc(' + (190) * 100 / 570 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(570 * 570px - 570 * 100%); -ko-width: @['calc('+ 570 * 570 + 'px - ' + 570 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="0" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 0px; border-spacing: 0px" width="190">
          
              <tr data-ko-display="fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 190px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 190px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="leftImage.src" width="190" height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=190%2C160" class="mobile-full"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 190px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 190px; height: auto" data-ko-editable="leftImage.src" width="190" data-ko-placeholder-height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=190%2C160" class="mobile-full"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
       --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="190"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 190px; -mru-width: 0px; min-width: calc(190 * 100% / 570); -ko-min-width: @['calc(' + (190) * 100 / 570 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(570 * 570px - 570 * 100%); -ko-width: @['calc('+ 570 * 570 + 'px - ' + 570 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="0" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 0px; border-spacing: 0px" width="190">
          
              <tr data-ko-display="fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 190px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="middleImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @middleImage.alt; width: 100%; max-width: 190px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="middleImage.src" width="190" height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=190%2C160" class="mobile-full"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 190px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="middleImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @middleImage.alt; width: 100%; max-width: 190px; height: auto" data-ko-editable="middleImage.src" width="190" data-ko-placeholder-height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=190%2C160" class="mobile-full"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
       --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="190"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 190px; -mru-width: 0px; min-width: calc(190 * 100% / 570); -ko-min-width: @['calc(' + (190) * 100 / 570 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(570 * 570px - 570 * 100%); -ko-width: @['calc('+ 570 * 570 + 'px - ' + 570 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="0" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 0px; border-spacing: 0px" width="190">
          
              <tr data-ko-display="fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 190px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 190px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="rightImage.src" width="190" height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=190%2C160" class="mobile-full"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 190px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 190px; height: auto" data-ko-editable="rightImage.src" width="190" data-ko-placeholder-height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=190%2C160" class="mobile-full"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
       --><!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
      <div data-ko-wrap="false" style="width: 100%; display:inline-block; display: none" data-ko-display="gutterVisible"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="width:100%; max-width: 552px; -mru-width: 0px"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="552"><tr><![endif]--><!--
        --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="184"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 184px; -mru-width: 0px; min-width: calc(184 * 100% / 552); -ko-min-width: @['calc(' + (184) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="184">
          
              <tr data-ko-display="fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 166px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="leftImage.src" width="166" height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C160"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="leftImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @leftImage.alt; width: 100%; max-width: 166px; height: auto" data-ko-editable="leftImage.src" width="166" data-ko-placeholder-height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C160"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
          --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="184"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 184px; -mru-width: 0px; min-width: calc(184 * 100% / 552); -ko-min-width: @['calc(' + (184) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="184">
          
              <tr data-ko-display="fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="middleImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @middleImage.alt; width: 100%; max-width: 166px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="middleImage.src" width="166" height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C160"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="middleImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @middleImage.alt; width: 100%; max-width: 166px; height: auto" data-ko-editable="middleImage.src" width="166" data-ko-placeholder-height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C160"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
          --><!--
            --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="184"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 184px; -mru-width: 0px; min-width: calc(184 * 100% / 552); -ko-min-width: @['calc(' + (184) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="184">
          
              <tr data-ko-display="fixedImageHeightVisible"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 166px; height: auto; -ko-attr-height: @[imageHeight]" data-ko-editable="rightImage.src" width="166" height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C160"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
              <tr data-ko-display="fixedImageHeightVisible eq false" style="display: none"><td width="100%" valign="top" align="center" class="links-color"><!--[if (lte ie 8)]><div style="display: inline-block; width: 166px; -mru-width: 0px"><![endif]--><a href="" data-ko-link="rightImage.url"><img alt="" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face; -ko-attr-alt: @rightImage.alt; width: 100%; max-width: 166px; height: auto" data-ko-editable="rightImage.src" width="166" data-ko-placeholder-height="160" src="https://mosaico.io/srv/f-default/img?method=placeholder&params=166%2C160"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
            
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
          --><!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
    </td></tr>
    </table>
    <!-- /tripleImageBlock -->
    

    
    <!-- bigSocialBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="bigSocialBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="18" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 18px; border-spacing: 18px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-container links-color socialLinks mobile-textcenter">
        
        <tr data-ko-display="bigSocialIconType eq 'colors'" style="display: none"><td width="100%" valign="top" style="font-weight: normal; text-align: center" align="center" class="links-color socialLinks mobile-textcenter">
          
            <span data-ko-wrap="false" data-ko-display="fbVisible">&nbsp;</span><a href="" data-ko-display="fbVisible" style="-ko-attr-href: @[fbUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #517bbe; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/fb-colors-96.png" width="48" height="48" alt="Facebook"></a>
          
            <span data-ko-wrap="false" data-ko-display="twVisible">&nbsp;</span><a href="" data-ko-display="twVisible" style="-ko-attr-href: @[twUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #64ccf1; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/tw-colors-96.png" width="48" height="48" alt="Twitter"></a>
          
            <span data-ko-wrap="false" data-ko-display="ggVisible">&nbsp;</span><a href="" data-ko-display="ggVisible" style="-ko-attr-href: @[ggUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #dc4e41; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/gg-colors-96.png" width="48" height="48" alt="Google"></a>
          
            <span data-ko-wrap="false" data-ko-display="webVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="webVisible" style="display: none; -ko-attr-href: @[webUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #5e5656; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/web-colors-96.png" width="48" height="48" alt="Web"></a>
          
            <span data-ko-wrap="false" data-ko-display="inVisible">&nbsp;</span><a href="" data-ko-display="inVisible" style="-ko-attr-href: @[inUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #0079ba; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/in-colors-96.png" width="48" height="48" alt="Linkedin"></a>
          
            <span data-ko-wrap="false" data-ko-display="piVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="piVisible" style="display: none; -ko-attr-href: @[piUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #bd091d; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/pi-colors-96.png" width="48" height="48" alt="Pinterest"></a>
          
            <span data-ko-wrap="false" data-ko-display="flVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="flVisible" style="display: none; -ko-attr-href: @[flUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #ff0082; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/fl-colors-96.png" width="48" height="48" alt="Flickr"></a>
          
            <span data-ko-wrap="false" data-ko-display="viVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="viVisible" style="display: none; -ko-attr-href: @[viUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #05b5ec; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/vi-colors-96.png" width="48" height="48" alt="Vimeo"></a>
          
            <span data-ko-wrap="false" data-ko-display="instVisible">&nbsp;</span><a href="" data-ko-display="instVisible" style="-ko-attr-href: @[instUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #4a79a3; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/inst-colors-96.png" width="48" height="48" alt="Instagram"></a>
          
            <span data-ko-wrap="false" data-ko-display="youVisible">&nbsp;</span><a href="" data-ko-display="youVisible" style="-ko-attr-href: @[youUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #ef2922; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/you-colors-96.png" width="48" height="48" alt="Youtube"></a>
          
        </td></tr>
        <tr data-ko-display="bigSocialIconType eq 'bw'" style="display: none"><td width="100%" valign="top" style="font-weight: normal; text-align: center" align="center" class="links-color socialLinks mobile-textcenter">
          
            <span data-ko-wrap="false" data-ko-display="fbVisible">&nbsp;</span><a href="" data-ko-display="fbVisible" style="-ko-attr-href: @[fbUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/fb-bw-96.png" width="48" height="48" alt="Facebook"></a>
          
            <span data-ko-wrap="false" data-ko-display="twVisible">&nbsp;</span><a href="" data-ko-display="twVisible" style="-ko-attr-href: @[twUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/tw-bw-96.png" width="48" height="48" alt="Twitter"></a>
          
            <span data-ko-wrap="false" data-ko-display="ggVisible">&nbsp;</span><a href="" data-ko-display="ggVisible" style="-ko-attr-href: @[ggUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/gg-bw-96.png" width="48" height="48" alt="Google"></a>
          
            <span data-ko-wrap="false" data-ko-display="webVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="webVisible" style="display: none; -ko-attr-href: @[webUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/web-bw-96.png" width="48" height="48" alt="Web"></a>
          
            <span data-ko-wrap="false" data-ko-display="inVisible">&nbsp;</span><a href="" data-ko-display="inVisible" style="-ko-attr-href: @[inUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/in-bw-96.png" width="48" height="48" alt="Linkedin"></a>
          
            <span data-ko-wrap="false" data-ko-display="piVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="piVisible" style="display: none; -ko-attr-href: @[piUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/pi-bw-96.png" width="48" height="48" alt="Pinterest"></a>
          
            <span data-ko-wrap="false" data-ko-display="flVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="flVisible" style="display: none; -ko-attr-href: @[flUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/fl-bw-96.png" width="48" height="48" alt="Flickr"></a>
          
            <span data-ko-wrap="false" data-ko-display="viVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="viVisible" style="display: none; -ko-attr-href: @[viUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/vi-bw-96.png" width="48" height="48" alt="Vimeo"></a>
          
            <span data-ko-wrap="false" data-ko-display="instVisible">&nbsp;</span><a href="" data-ko-display="instVisible" style="-ko-attr-href: @[instUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/inst-bw-96.png" width="48" height="48" alt="Instagram"></a>
          
            <span data-ko-wrap="false" data-ko-display="youVisible">&nbsp;</span><a href="" data-ko-display="youVisible" style="-ko-attr-href: @[youUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/you-bw-96.png" width="48" height="48" alt="Youtube"></a>
          
        </td></tr>
        <tr data-ko-display="bigSocialIconType eq 'rdcol'"><td width="100%" valign="top" style="font-weight: normal; text-align: center" align="center" class="links-color socialLinks mobile-textcenter">
          
            <span data-ko-wrap="false" data-ko-display="fbVisible">&nbsp;</span><a href="" data-ko-display="fbVisible" style="-ko-attr-href: @[fbUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/fb-rdcol-96.png" width="48" height="48" alt="Facebook"></a>
          
            <span data-ko-wrap="false" data-ko-display="twVisible">&nbsp;</span><a href="" data-ko-display="twVisible" style="-ko-attr-href: @[twUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/tw-rdcol-96.png" width="48" height="48" alt="Twitter"></a>
          
            <span data-ko-wrap="false" data-ko-display="ggVisible">&nbsp;</span><a href="" data-ko-display="ggVisible" style="-ko-attr-href: @[ggUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/gg-rdcol-96.png" width="48" height="48" alt="Google"></a>
          
            <span data-ko-wrap="false" data-ko-display="webVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="webVisible" style="display: none; -ko-attr-href: @[webUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/web-rdcol-96.png" width="48" height="48" alt="Web"></a>
          
            <span data-ko-wrap="false" data-ko-display="inVisible">&nbsp;</span><a href="" data-ko-display="inVisible" style="-ko-attr-href: @[inUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/in-rdcol-96.png" width="48" height="48" alt="Linkedin"></a>
          
            <span data-ko-wrap="false" data-ko-display="piVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="piVisible" style="display: none; -ko-attr-href: @[piUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/pi-rdcol-96.png" width="48" height="48" alt="Pinterest"></a>
          
            <span data-ko-wrap="false" data-ko-display="flVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="flVisible" style="display: none; -ko-attr-href: @[flUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/fl-rdcol-96.png" width="48" height="48" alt="Flickr"></a>
          
            <span data-ko-wrap="false" data-ko-display="viVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="viVisible" style="display: none; -ko-attr-href: @[viUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/vi-rdcol-96.png" width="48" height="48" alt="Vimeo"></a>
          
            <span data-ko-wrap="false" data-ko-display="instVisible">&nbsp;</span><a href="" data-ko-display="instVisible" style="-ko-attr-href: @[instUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/inst-rdcol-96.png" width="48" height="48" alt="Instagram"></a>
          
            <span data-ko-wrap="false" data-ko-display="youVisible">&nbsp;</span><a href="" data-ko-display="youVisible" style="-ko-attr-href: @[youUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/you-rdcol-96.png" width="48" height="48" alt="Youtube"></a>
          
        </td></tr>
        <tr data-ko-display="bigSocialIconType eq 'rdbl'" style="display: none"><td width="100%" valign="top" style="font-weight: normal; text-align: center" align="center" class="links-color socialLinks mobile-textcenter">
          
            <span data-ko-wrap="false" data-ko-display="fbVisible">&nbsp;</span><a href="" data-ko-display="fbVisible" style="-ko-attr-href: @[fbUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/fb-rdbl-96.png" width="48" height="48" alt="Facebook"></a>
          
            <span data-ko-wrap="false" data-ko-display="twVisible">&nbsp;</span><a href="" data-ko-display="twVisible" style="-ko-attr-href: @[twUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/tw-rdbl-96.png" width="48" height="48" alt="Twitter"></a>
          
            <span data-ko-wrap="false" data-ko-display="ggVisible">&nbsp;</span><a href="" data-ko-display="ggVisible" style="-ko-attr-href: @[ggUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/gg-rdbl-96.png" width="48" height="48" alt="Google"></a>
          
            <span data-ko-wrap="false" data-ko-display="webVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="webVisible" style="display: none; -ko-attr-href: @[webUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/web-rdbl-96.png" width="48" height="48" alt="Web"></a>
          
            <span data-ko-wrap="false" data-ko-display="inVisible">&nbsp;</span><a href="" data-ko-display="inVisible" style="-ko-attr-href: @[inUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/in-rdbl-96.png" width="48" height="48" alt="Linkedin"></a>
          
            <span data-ko-wrap="false" data-ko-display="piVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="piVisible" style="display: none; -ko-attr-href: @[piUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/pi-rdbl-96.png" width="48" height="48" alt="Pinterest"></a>
          
            <span data-ko-wrap="false" data-ko-display="flVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="flVisible" style="display: none; -ko-attr-href: @[flUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/fl-rdbl-96.png" width="48" height="48" alt="Flickr"></a>
          
            <span data-ko-wrap="false" data-ko-display="viVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="viVisible" style="display: none; -ko-attr-href: @[viUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/vi-rdbl-96.png" width="48" height="48" alt="Vimeo"></a>
          
            <span data-ko-wrap="false" data-ko-display="instVisible">&nbsp;</span><a href="" data-ko-display="instVisible" style="-ko-attr-href: @[instUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/inst-rdbl-96.png" width="48" height="48" alt="Instagram"></a>
          
            <span data-ko-wrap="false" data-ko-display="youVisible">&nbsp;</span><a href="" data-ko-display="youVisible" style="-ko-attr-href: @[youUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; -ko-attr-width: @[bigSocialIconSize]; -ko-attr-height: @[bigSocialIconSize]; border-radius: 50px" src="img/icons/you-rdbl-96.png" width="48" height="48" alt="Youtube"></a>
          
        </td></tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
    </td></tr>
    </table>
    <!-- /bigSocialBlock -->
    

    
    <!-- shareBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="shareBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <div data-ko-wrap="false" style="width: 100%; display:inline-block" data-ko-display="shareButtonType eq 'reverse'"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="width:100%"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0"><tr><![endif]--><!--
        -->
          
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="fbVisible"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="fbVisible"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #3b5998; border-radius: 4px; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#3b5998"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://www.facebook.com/sharer/sharer.php?u=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/fb-white-96.png" alt="Facebook" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://www.facebook.com/sharer/sharer.php?u=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="fbText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="twVisible"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="twVisible"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #4099FF; border-radius: 4px; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#4099FF"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://twitter.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/tw-white-96.png" alt="Twitter" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://twitter.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="twText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block; display: none" class="mobile-full" data-ko-display="inVisible"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="inVisible" style="display: none"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #007bb6; border-radius: 4px; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#007bb6"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://www.linkedin.com/shareArticle?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/in-white-96.png" alt="LinkedIn" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://www.linkedin.com/shareArticle?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="inText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="ggVisible"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="ggVisible"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #d34836; border-radius: 4px; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#d34836"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://plus.google.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/gg-white-96.png" alt="Google+" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://plus.google.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="ggText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block; display: none" class="mobile-full" data-ko-display="piVisible"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="piVisible" style="display: none"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #C92228; border-radius: 4px; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#C92228"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://pinterest.com/pin/find/?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/pi-white-96.png" alt="Pinterest" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://pinterest.com/pin/find/?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #FFFFFF; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="piText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
        <!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
      <div data-ko-wrap="false" style="width: 100%; display:inline-block; display: none" data-ko-display="shareButtonType eq 'simple'"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="width:100%"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0"><tr><![endif]--><!--
        -->
          
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="fbVisible"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="fbVisible"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #FFFFFF; border-radius: 4px" bgcolor="#FFFFFF"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://www.facebook.com/sharer/sharer.php?u=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/fb-coloured-96.png" alt="Facebook" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://www.facebook.com/sharer/sharer.php?u=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="fbText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="twVisible"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="twVisible"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #FFFFFF; border-radius: 4px" bgcolor="#FFFFFF"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://twitter.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/tw-coloured-96.png" alt="Twitter" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://twitter.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="twText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block; display: none" class="mobile-full" data-ko-display="inVisible"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="inVisible" style="display: none"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #FFFFFF; border-radius: 4px" bgcolor="#FFFFFF"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://www.linkedin.com/shareArticle?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/in-coloured-96.png" alt="LinkedIn" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://www.linkedin.com/shareArticle?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="inText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="ggVisible"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="ggVisible"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #FFFFFF; border-radius: 4px" bgcolor="#FFFFFF"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://plus.google.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/gg-coloured-96.png" alt="Google+" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://plus.google.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="ggText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block; display: none" class="mobile-full" data-ko-display="piVisible"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="piVisible" style="display: none"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #FFFFFF; border-radius: 4px" bgcolor="#FFFFFF"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://pinterest.com/pin/find/?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/pi-coloured-96.png" alt="Pinterest" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://pinterest.com/pin/find/?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #000000; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="piText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
        <!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
      <div data-ko-wrap="false" style="width: 100%; display:inline-block; display: none" data-ko-display="shareButtonType eq 'custom'"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="width:100%"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0"><tr><![endif]--><!--
        -->
          
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="fbVisible and shareButtonStyle.iconColorType eq 'brand'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="fbVisible and shareButtonStyle.iconColorType eq 'brand'"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://www.facebook.com/sharer/sharer.php?u=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/fb-coloured-96.png" alt="Facebook" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://www.facebook.com/sharer/sharer.php?u=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="fbText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="fbVisible and shareButtonStyle.iconColorType eq 'white'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="fbVisible and shareButtonStyle.iconColorType eq 'white'"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://www.facebook.com/sharer/sharer.php?u=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/fb-white-96.png" alt="Facebook" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://www.facebook.com/sharer/sharer.php?u=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="fbText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="fbVisible and shareButtonStyle.iconColorType eq 'black'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="fbVisible and shareButtonStyle.iconColorType eq 'black'"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://www.facebook.com/sharer/sharer.php?u=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/fb-black-96.png" alt="Facebook" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://www.facebook.com/sharer/sharer.php?u=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="fbText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="twVisible and shareButtonStyle.iconColorType eq 'brand'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="twVisible and shareButtonStyle.iconColorType eq 'brand'"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://twitter.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/tw-coloured-96.png" alt="Twitter" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://twitter.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="twText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="twVisible and shareButtonStyle.iconColorType eq 'white'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="twVisible and shareButtonStyle.iconColorType eq 'white'"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://twitter.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/tw-white-96.png" alt="Twitter" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://twitter.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="twText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="twVisible and shareButtonStyle.iconColorType eq 'black'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="twVisible and shareButtonStyle.iconColorType eq 'black'"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://twitter.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/tw-black-96.png" alt="Twitter" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://twitter.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="twText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block; display: none" class="mobile-full" data-ko-display="inVisible and shareButtonStyle.iconColorType eq 'brand'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="inVisible and shareButtonStyle.iconColorType eq 'brand'" style="display: none"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://www.linkedin.com/shareArticle?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/in-coloured-96.png" alt="LinkedIn" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://www.linkedin.com/shareArticle?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="inText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
            <div data-ko-wrap="false" style="display:inline-block; display: none" class="mobile-full" data-ko-display="inVisible and shareButtonStyle.iconColorType eq 'white'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="inVisible and shareButtonStyle.iconColorType eq 'white'" style="display: none"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://www.linkedin.com/shareArticle?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/in-white-96.png" alt="LinkedIn" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://www.linkedin.com/shareArticle?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="inText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
            <div data-ko-wrap="false" style="display:inline-block; display: none" class="mobile-full" data-ko-display="inVisible and shareButtonStyle.iconColorType eq 'black'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="inVisible and shareButtonStyle.iconColorType eq 'black'" style="display: none"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://www.linkedin.com/shareArticle?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/in-black-96.png" alt="LinkedIn" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://www.linkedin.com/shareArticle?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="inText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="ggVisible and shareButtonStyle.iconColorType eq 'brand'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="ggVisible and shareButtonStyle.iconColorType eq 'brand'"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://plus.google.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/gg-coloured-96.png" alt="Google+" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://plus.google.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="ggText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="ggVisible and shareButtonStyle.iconColorType eq 'white'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="ggVisible and shareButtonStyle.iconColorType eq 'white'"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://plus.google.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/gg-white-96.png" alt="Google+" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://plus.google.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="ggText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
            <div data-ko-wrap="false" style="display:inline-block" class="mobile-full" data-ko-display="ggVisible and shareButtonStyle.iconColorType eq 'black'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="ggVisible and shareButtonStyle.iconColorType eq 'black'"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://plus.google.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/gg-black-96.png" alt="Google+" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://plus.google.com/share?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="ggText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
            <div data-ko-wrap="false" style="display:inline-block; display: none" class="mobile-full" data-ko-display="piVisible and shareButtonStyle.iconColorType eq 'brand'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="piVisible and shareButtonStyle.iconColorType eq 'brand'" style="display: none"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://pinterest.com/pin/find/?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/pi-coloured-96.png" alt="Pinterest" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://pinterest.com/pin/find/?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="piText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
            <div data-ko-wrap="false" style="display:inline-block; display: none" class="mobile-full" data-ko-display="piVisible and shareButtonStyle.iconColorType eq 'white'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="piVisible and shareButtonStyle.iconColorType eq 'white'" style="display: none"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://pinterest.com/pin/find/?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/pi-white-96.png" alt="Pinterest" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://pinterest.com/pin/find/?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="piText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
            <div data-ko-wrap="false" style="display:inline-block; display: none" class="mobile-full" data-ko-display="piVisible and shareButtonStyle.iconColorType eq 'black'"><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" data-ko-display="piVisible and shareButtonStyle.iconColorType eq 'black'" style="display: none"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; mso-cellspacing: 9px; border-spacing: 9px" align="center">
          
              <tr>
      <td valign="top" style="line-height: 24px;"><table cellpadding="0" border="0" align="center" cellspacing="6" style="border-spacing: 0; mso-cellspacing: 6px; border-collapse: separate; border-spacing: 6px; background-color: #bfbfbf; border-radius: 4px; -ko-attr-bgcolor: @shareButtonStyle.buttonColor; -ko-background-color: @shareButtonStyle.buttonColor; -ko-border-radius: @[shareButtonStyle.radius]px;" bgcolor="#bfbfbf"><tr>
        <td class="shareIcon" valign="middle" style="font-weight: normal; padding-left: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;" width="24"><a href="http://pinterest.com/pin/find/?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><img style="display: block" src="img/icons/pi-black-96.png" alt="Pinterest" width="24" height="24"></a></td>
        <td width="auto" valign="middle" style="font-weight: normal; padding-right: 4px; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face; line-height: 24px;"><a href="http://pinterest.com/pin/find/?url=%5Bpermlink_urlenc%5D" style="text-decoration: none; font-weight: normal; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-color: @shareButtonStyle.color; -ko-font-size: @[shareButtonStyle.size]px; -ko-font-family: @shareButtonStyle.face"><span data-ko-wrap="false" data-ko-editable="piText">Share
            </span></a></td>
      </tr></table></td>
    </tr>
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--></div>
          
        <!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
    </td></tr>
    </table>
    <!-- /shareBlock -->
    

    
    <!-- spacerBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#bfbfbf" style="background-color: #bfbfbf; -ko-background-color: @[externalBackgroundColor]; -ko-attr-bgcolor: @[externalBackgroundColor]" data-ko-block="spacerBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0; font-size:1px; height: 1px; height: 24px; -ko-height: @[spacerSize]px; -ko-attr-height: @[spacerSize]" height="24">
      <div data-ko-wrap="false" style="width: 100%; display:inline-block; display: none" data-ko-display="externalBackgroundVisible eq false"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="0" style="border-collapse: separate; width: 100%; background-color: #ffffff; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]; max-width: 570px; -mru-width: 0px" bgcolor="#ffffff" width="570" class="vb-container">
        
        <tr>
        <td width="100%" height="24" style="padding: 0; font-size:1px; line-height: 1px; width: 100%; line-height: 24px; -ko-line-height: @[spacerSize]px; -ko-attr-height: @[spacerSize]">&nbsp;</td>
      </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]--></div>
      <div data-ko-display="externalBackgroundVisible" data-ko-wrap="false">&nbsp;</div>
    </td></tr>
    </table>
    <!-- /spacerBlock -->
    


    
    <!-- socialBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#3f3f3f" style="background-color: #3f3f3f; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]" data-ko-block="socialBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
      <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="9" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px; max-width: 570px; -mru-width: 0px" width="570" class="vb-row">
        
        <tr>
      <td align="center" valign="top" style="font-size: 0"><div style="width:100%; max-width: 552px; -mru-width: 0px"><!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="552"><tr><![endif]--><!--
        --><!--
          --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="276"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 276px; -mru-width: 0px; min-width: calc(276 * 100% / 552); -ko-min-width: @['calc(' + (276) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="276">
          
            <tr><td class="long-text links-color" width="100%" valign="top" style="font-weight: normal; color: #919191; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: left; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face" align="left" data-ko-editable="longText"><p>Address and <a href="">Contacts</a></p></td></tr>
          
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
          --><!--[if (gte mso 9)|(lte ie 8)]><td align="left" valign="top" width="276"><![endif]--><!--
      --><div style="display:inline-block; vertical-align:top; width: 100%; max-width: 276px; -mru-width: 0px; min-width: calc(276 * 100% / 552); -ko-min-width: @['calc(' + (276) * 100 / 552 + '%)']; max-width: calc(100%); -ko-max-width: @['calc(100%)']; width: calc(552 * 552px - 552 * 100%); -ko-width: @['calc('+ 552 * 552 + 'px - ' + 552 * 100 +'%)']" class="mobile-full"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="276">
          
            <tr data-ko-display="socialIconType eq 'colors'"><td width="100%" valign="top" style="font-weight: normal; text-align: right" align="right" class="links-color socialLinks mobile-textcenter">
              
                <span data-ko-wrap="false" data-ko-display="fbVisible">&nbsp;</span><a href="" data-ko-display="fbVisible" style="-ko-attr-href: @[fbUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #517bbe; border-radius: 50px" src="img/icons/fb-colors-96.png" width="32" height="32" alt="Facebook"></a>
              
                <span data-ko-wrap="false" data-ko-display="twVisible">&nbsp;</span><a href="" data-ko-display="twVisible" style="-ko-attr-href: @[twUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #64ccf1; border-radius: 50px" src="img/icons/tw-colors-96.png" width="32" height="32" alt="Twitter"></a>
              
                <span data-ko-wrap="false" data-ko-display="ggVisible">&nbsp;</span><a href="" data-ko-display="ggVisible" style="-ko-attr-href: @[ggUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #dc4e41; border-radius: 50px" src="img/icons/gg-colors-96.png" width="32" height="32" alt="Google"></a>
              
                <span data-ko-wrap="false" data-ko-display="webVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="webVisible" style="display: none; -ko-attr-href: @[webUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #5e5656; border-radius: 50px" src="img/icons/web-colors-96.png" width="32" height="32" alt="Web"></a>
              
                <span data-ko-wrap="false" data-ko-display="inVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="inVisible" style="display: none; -ko-attr-href: @[inUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #0079ba; border-radius: 50px" src="img/icons/in-colors-96.png" width="32" height="32" alt="Linkedin"></a>
              
                <span data-ko-wrap="false" data-ko-display="piVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="piVisible" style="display: none; -ko-attr-href: @[piUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #bd091d; border-radius: 50px" src="img/icons/pi-colors-96.png" width="32" height="32" alt="Pinterest"></a>
              
                <span data-ko-wrap="false" data-ko-display="flVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="flVisible" style="display: none; -ko-attr-href: @[flUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #ff0082; border-radius: 50px" src="img/icons/fl-colors-96.png" width="32" height="32" alt="Flickr"></a>
              
                <span data-ko-wrap="false" data-ko-display="viVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="viVisible" style="display: none; -ko-attr-href: @[viUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #05b5ec; border-radius: 50px" src="img/icons/vi-colors-96.png" width="32" height="32" alt="Vimeo"></a>
              
                <span data-ko-wrap="false" data-ko-display="instVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="instVisible" style="display: none; -ko-attr-href: @[instUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #4a79a3; border-radius: 50px" src="img/icons/inst-colors-96.png" width="32" height="32" alt="Instagram"></a>
              
                <span data-ko-wrap="false" data-ko-display="youVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="youVisible" style="display: none; -ko-attr-href: @[youUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #ef2922; border-radius: 50px" src="img/icons/you-colors-96.png" width="32" height="32" alt="Youtube"></a>
              
            </td></tr>
            <tr data-ko-display="socialIconType eq 'bw'" style="display: none"><td width="100%" valign="top" style="font-weight: normal; text-align: right" align="right" class="links-color socialLinks mobile-textcenter">
              
                <span data-ko-wrap="false" data-ko-display="fbVisible">&nbsp;</span><a href="" data-ko-display="fbVisible" style="-ko-attr-href: @[fbUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; border-radius: 50px" src="img/icons/fb-bw-96.png" width="32" height="32" alt="Facebook"></a>
              
                <span data-ko-wrap="false" data-ko-display="twVisible">&nbsp;</span><a href="" data-ko-display="twVisible" style="-ko-attr-href: @[twUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; border-radius: 50px" src="img/icons/tw-bw-96.png" width="32" height="32" alt="Twitter"></a>
              
                <span data-ko-wrap="false" data-ko-display="ggVisible">&nbsp;</span><a href="" data-ko-display="ggVisible" style="-ko-attr-href: @[ggUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; border-radius: 50px" src="img/icons/gg-bw-96.png" width="32" height="32" alt="Google"></a>
              
                <span data-ko-wrap="false" data-ko-display="webVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="webVisible" style="display: none; -ko-attr-href: @[webUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; border-radius: 50px" src="img/icons/web-bw-96.png" width="32" height="32" alt="Web"></a>
              
                <span data-ko-wrap="false" data-ko-display="inVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="inVisible" style="display: none; -ko-attr-href: @[inUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; border-radius: 50px" src="img/icons/in-bw-96.png" width="32" height="32" alt="Linkedin"></a>
              
                <span data-ko-wrap="false" data-ko-display="piVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="piVisible" style="display: none; -ko-attr-href: @[piUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; border-radius: 50px" src="img/icons/pi-bw-96.png" width="32" height="32" alt="Pinterest"></a>
              
                <span data-ko-wrap="false" data-ko-display="flVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="flVisible" style="display: none; -ko-attr-href: @[flUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; border-radius: 50px" src="img/icons/fl-bw-96.png" width="32" height="32" alt="Flickr"></a>
              
                <span data-ko-wrap="false" data-ko-display="viVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="viVisible" style="display: none; -ko-attr-href: @[viUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; border-radius: 50px" src="img/icons/vi-bw-96.png" width="32" height="32" alt="Vimeo"></a>
              
                <span data-ko-wrap="false" data-ko-display="instVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="instVisible" style="display: none; -ko-attr-href: @[instUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; border-radius: 50px" src="img/icons/inst-bw-96.png" width="32" height="32" alt="Instagram"></a>
              
                <span data-ko-wrap="false" data-ko-display="youVisible" style="display: none">&nbsp;</span><a href="" data-ko-display="youVisible" style="display: none; -ko-attr-href: @[youUrl]"><img border="0" style="display: inline-block; vertical-align: top; padding-bottom: 0px; background: url(), #818181; border-radius: 50px" src="img/icons/you-bw-96.png" width="32" height="32" alt="Youtube"></a>
              
            </td></tr>
          
        </table><!--
      --></div><!--[if (gte mso 9)|(lte ie 8)]></td><![endif]--><!--
        --><!--
      --><!--[if (gte mso 9)|(lte ie 8)]></tr></table><![endif]--></div></td>
    </tr>
      
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
    </td></tr>
    </table>
    <!-- /socialBlock -->
    

  </div>

  
    <!-- footerBlock -->
    <table class="vb-outer" width="100%" cellpadding="0" border="0" cellspacing="0" bgcolor="#3f3f3f" style="background-color: #3f3f3f; -ko-background-color: @[backgroundColor]; -ko-attr-bgcolor: @[backgroundColor]" data-ko-block="footerBlock">
      <tr><td class="vb-outer" align="center" valign="top" style="padding-left: 9px; padding-right: 9px; font-size: 0">
    <!--[if (gte mso 9)|(lte ie 8)]><table align="center" border="0" cellspacing="0" cellpadding="0" width="570"><tr><td align="center" valign="top"><![endif]--><!--
      --><div style="margin: 0 auto; max-width: 570px; -mru-width: 0px"><table border="0" cellpadding="0" cellspacing="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 0px; border-spacing: 0px; max-width: 570px; -mru-width: 0px" width="570" class="vb-row">
        
      <tr>
      <td align="center" valign="top" style="font-size: 0; padding: 0 9px"><div style="display:inline-block; vertical-align:top; width:100%; max-width: 552px; -mru-width: 0px"><!--
        --><table class="vb-content" border="0" cellspacing="9" cellpadding="0" style="border-collapse: separate; width: 100%; mso-cellspacing: 9px; border-spacing: 9px" width="552">
          
        <tr><td class="long-text links-color" width="100%" valign="top" style="font-weight: normal; color: #919191; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: center; -ko-font-size: @[longTextStyle.size]px; -ko-color: @longTextStyle.color; -ko-font-family: @longTextStyle.face" align="center" data-ko-editable="longText"><p>Email sent to <a href="mailto:[mail]">[mail]</a></p></td></tr>
        <tr><td width="100%" valign="top" style="font-weight: normal; color: #ffffff; font-size: 13px; font-family: Arial, Helvetica, sans-serif; text-align: center; -ko-font-size: @[linkStyle.size]px; -ko-color: @linkStyle.color; -ko-font-family: @linkStyle.face" align="center"><a style="color: #ffffff; -ko-color: @[Color.readability(linkStyle.color, backgroundColor) gt 2 ? linkStyle.color : (Color.isReadable('#ffffff', backgroundColor) ? '#ffffff' : '#000000')]; text-decoration: underline; -ko-color: @linkStyle.color; -ko-text-decoration: @linkStyle.decoration" href="[unsubscribe_link]" data-ko-editable="disiscrivitiText">Unsubscribe</a></td></tr>
        <tr data-ko-display="_root_.sponsor.visible" style="display: none; text-align: center"><td width="100%" valign="top" align="center" class="links-color" style="text-align: center"><!--[if (lte ie 8)]><div style="display: inline-block; width: 170px; -mru-width: 0px"><![endif]--><a href="" style="-ko-attr-href: @_root_.sponsor.url"><img alt="sponsor" border="0" hspace="0" align="center" vspace="0" style="vertical-align:top; height: auto; margin: 0 auto; color: #3f3f3f; font-size: 13px; font-family: Arial, Helvetica, sans-serif; -ko-attr-src: @_root_.sponsor.src; -ko-attr-alt: @_root_.sponsor.alt; width: 100%; max-width: 170px" width="170" src="img/sponsor.gif"></a><!--[if (lte ie 8)]></div><![endif]--></td></tr>
        </table></div></td>
    </tr>
    
      </table></div><!--
    --><!--[if (gte mso 9)|(lte ie 8)]></td></tr></table><![endif]-->
  </td></tr>
    </table>
    <!-- /footerBlock -->
    
</center></body></html>